==> multitail-4.0.3.tgz: multitail-4.0.3/globals.h <==
extern proginfo *pi;
extern buffer *lb;
extern int nfd;
extern int max_y, max_x;
extern char terminal_changed;
extern char split;
extern char banner;
extern NEWWIN **splitlines;
extern int n_splitlines;
extern NEWWIN *menu_win;
extern int mode_statusline;
extern char warn_closed;
extern char use_colors;
extern int min_n_bufferlines;
extern color_scheme *cschemes;
extern int n_cschemes;
extern pars_per_file *ppf;
extern int n_pars_per_file;
extern char do_refresh;
extern char mail;
extern int check_for_mail;
extern char tab_width;
extern time_t mt_started;
extern int *vertical_split;
extern int *n_win_per_col;
extern int terminal_index;
extern char prev_term_char;
extern int n_keybindings;
extern keybinding *keybindings;
extern char *set_title;
extern pid_t tail_proc;
extern char bright_colors;
extern char *mail_spool_file;
extern struct stat64 msf_info;
extern off64_t msf_prev_size;
extern time_t msf_last_check;
extern int update_interval;
extern char *tail;
extern char afs;
extern colorpairs cp;
extern char show_subwindow_id;
extern myattr_t markerline_attrs;
extern myattr_t changeline_attrs;
extern myattr_t idleline_attrs;
extern myattr_t statusline_attrs;
extern myattr_t msgline_attrs;
extern char timestamp_in_markerline;
extern double heartbeat_t;
extern double heartbeat_interval;
extern const char *version_str;
extern char *ts_format;
extern char *statusline_ts_format;
extern char *cnv_ts_format;
extern conversion *conversions;
extern int n_conversions;
extern char *shell;
extern char no_linewrap;
extern char *config_file;
extern char got_sighup;
extern char filename_only;
extern int default_color_scheme;
extern char *nsubwindows;
extern char allow_8bit;
extern char **color_names;
extern int n_colors_defined;
extern beeb_t beep_method;
extern double beep_popup_length;
extern char caret_notation;
extern mode_t def_umask;
extern check_dir_glob *cdg;
extern int n_cdg;
extern char statusline_above_data;
extern char *F1;
extern int default_maxnlines;
extern int default_maxbytes;
extern int popup_refresh_interval;
extern char global_marker_of_other_window;
extern char markerline_char;
extern char changeline_char;
extern char idleline_char;
extern char msgline_char;
extern char *replace_by_markerline;
extern char default_bufferwhat;

extern color_scheme *cschemes;
extern int n_cschemes;
extern colorpairs cp;

extern pid_t children_list[MAX_N_SPAWNED_PROCESSES];
extern int n_children;

extern term_t term_type;

==> multitail-4.0.6.tgz: multitail-4.0.6/globals.h <==
extern proginfo *pi;
extern buffer *lb;
extern int nfd;
extern int max_y, max_x;
extern char terminal_changed;
extern char split;
extern char banner;
extern NEWWIN **splitlines;
extern int n_splitlines;
extern NEWWIN *menu_win;
extern int mode_statusline;
extern char warn_closed;
extern char use_colors;
extern int min_n_bufferlines;
extern color_scheme *cschemes;
extern int n_cschemes;
extern pars_per_file *ppf;
extern int n_pars_per_file;
extern char do_refresh;
extern char mail;
extern int check_for_mail;
extern char tab_width;
extern time_t mt_started;
extern int *vertical_split;
extern int *n_win_per_col;
extern int terminal_index;
extern char prev_term_char;
extern int n_keybindings;
extern keybinding *keybindings;
extern char *set_title;
extern pid_t tail_proc;
extern char bright_colors;
extern char *mail_spool_file;
extern struct stat64 msf_info;
extern off64_t msf_prev_size;
extern time_t msf_last_check;
extern int update_interval;
extern char *tail;
extern char afs;
extern colorpairs cp;
extern char show_subwindow_id;
extern myattr_t markerline_attrs;
extern myattr_t changeline_attrs;
extern myattr_t idleline_attrs;
extern myattr_t statusline_attrs;
extern myattr_t msgline_attrs;
extern char timestamp_in_markerline;
extern double heartbeat_t;
extern double heartbeat_interval;
extern const char *version_str;
extern char *ts_format;
extern char *statusline_ts_format;
extern char *cnv_ts_format;
extern conversion *conversions;
extern int n_conversions;
extern char *shell;
extern char no_linewrap;
extern char *config_file;
extern char got_sigusr1;
extern char filename_only;
extern int default_color_scheme;
extern char *nsubwindows;
extern char allow_8bit;
extern char **color_names;
extern int n_colors_defined;
extern beeb_t beep_method;
extern double beep_popup_length;
extern char caret_notation;
extern mode_t def_umask;
extern check_dir_glob *cdg;
extern int n_cdg;
extern char statusline_above_data;
extern char *F1;
extern int default_maxnlines;
extern int default_maxbytes;
extern int popup_refresh_interval;
extern char global_marker_of_other_window;
extern char markerline_char;
extern char changeline_char;
extern char idleline_char;
extern char msgline_char;
extern char *replace_by_markerline;
extern char default_bufferwhat;

extern color_scheme *cschemes;
extern int n_cschemes;
extern colorpairs cp;

extern pid_t children_list[MAX_N_SPAWNED_PROCESSES];
extern int n_children;

extern term_t term_type;
